pub struct CommandSuggestionContext<'context> {
inner: &'context dyn SteelArgumentSuggestionContext,
}Expand description
Prior parsed values and source facts available to custom suggestions.
Fields
inner: &'context dyn SteelArgumentSuggestionContextImplementations
Sourceimpl<'context> CommandSuggestionContext<'context>
impl<'context> CommandSuggestionContext<'context>
Sourcepub fn source(&self) -> CommandParserSource<'context>
pub fn source(&self) -> CommandParserSource<'context>
Returns source facts for context-aware completion.
Sourcepub fn value<T: DowncastType>(&self, name: &str) -> Option<&'context T>
pub fn value<T: DowncastType>(&self, name: &str) -> Option<&'context T>
Returns a previously parsed custom value by deterministic concrete type key.